﻿IF EXISTS (SELECT 1 FROM sys.columns WHERE object_id=object_id('[FNS_FeedASIN]')) and 
	not EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[FNS_FeedASIN]') AND name = N'IX_FNS_FeedASIN_ASIN')
	CREATE NONCLUSTERED INDEX IX_FNS_FeedASIN_ASIN ON FNS_FeedASIN ([ASIN] DESC) 
GO
IF EXISTS (SELECT 1 FROM sys.columns WHERE object_id=object_id('[FNS_FeedEPID]')) and 
	not EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[FNS_FeedEPID]') AND name = N'IX_FNS_FeedEPID_EPID')
	CREATE NONCLUSTERED INDEX IX_FNS_FeedEPID_EPID ON FNS_FeedEPID ([EPID] DESC) 
GO
IF not EXISTS (SELECT * FROM sys.indexes WHERE object_id = OBJECT_ID(N'[Product_SpecificationAttribute_Mapping]') AND name = N'IX_PSAM_ProductId')
	CREATE NONCLUSTERED INDEX [IX_PSAM_ProductId] ON [Product_SpecificationAttribute_Mapping] ([ProductId] ASC) 
GO
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[feedmanager_splitstring_to_table]') AND type in (N'FN', N'IF', N'TF', N'FS', N'FT'))
DROP FUNCTION [feedmanager_splitstring_to_table]
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE FUNCTION [dbo].[feedmanager_splitstring_to_table]
(
    @string NVARCHAR(MAX),
    @delimiter CHAR(1)
)
RETURNS @output TABLE(
    data NVARCHAR(MAX)
)
BEGIN
    DECLARE @start INT, @end INT
    SELECT @start = 1, @end = CHARINDEX(@delimiter, @string)

    WHILE @start < LEN(@string) + 1 BEGIN
        IF @end = 0 
            SET @end = LEN(@string) + 1

        INSERT INTO @output (data) 
        VALUES(SUBSTRING(@string, @start, @end - @start))
        SET @start = @end + 1
        SET @end = CHARINDEX(@delimiter, @string, @start)
    END
    RETURN
END
GO
IF  EXISTS (SELECT * FROM sys.objects WHERE object_id = OBJECT_ID(N'[FNS_FeedManager_ProductLoadAll]') AND type in (N'P', N'PC'))
DROP PROCEDURE [FNS_FeedManager_ProductLoadAll]
GO
SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO
CREATE PROCEDURE [FNS_FeedManager_ProductLoadAll]
(
	@FeedId		int,	
	@AllowedCustomerRoleIds	nvarchar(MAX) = null,	--a list of customer role IDs (comma-separated list) for which a product should be shown (if a subjet to ACL)
	@PageIndex			int = 0, 
	@PageSize			int = 2147483644,
	@DisplayUnexportedProducts bit=0
)
AS
BEGIN
SET NOCOUNT ON
DECLARE @StoreId int, @LanguageId int, @ExportGrouped bit
select @StoreId=StoreId, @LanguageId=LanguageId, @ExportGrouped = ExportGrouped from FNS_FeedRec WITH (NOLOCK) where Id=@FeedId
if @LanguageId>0
begin	
	declare @countLanguage int
	set @countLanguage=0
	select @countLanguage=count(*) from [Language] L WITH (NOLOCK) 
	if @countLanguage=1
	begin
		set @LanguageId=0
	end
end
if @StoreId>0
begin	
	declare @countStores int
	set @countStores=0
	select @countStores=count(*) from [Store] S WITH (NOLOCK) 
	if @countStores=1
	begin
		set @StoreId=0
	end
end


DECLARE @sql nvarchar(max)

	CREATE TABLE #ExportProductsTmp
	(
		[ProductId] int NOT NULL,
		[ProductTypeId] int NOT NULL,
		[VisibleIndividually] bit NOT NULL,
		[ParentGroupedProductId] int NOT NULL
	)
	
	--filter by customer role IDs (access control list)
	SET @AllowedCustomerRoleIds = isnull(@AllowedCustomerRoleIds, '')	
	CREATE TABLE #FilteredCustomerRoleIds
	(
		CustomerRoleId int not null
	)
	INSERT INTO #FilteredCustomerRoleIds (CustomerRoleId)
	SELECT CAST(data as int) FROM [feedmanager_splitstring_to_table](@AllowedCustomerRoleIds, ',')

		--product name
		SET @sql = 'INSERT INTO #ExportProductsTmp (ProductId,ProductTypeId,VisibleIndividually,ParentGroupedProductId)
		SELECT p.Id, p.ProductTypeId, p.VisibleIndividually, p.ParentGroupedProductId
		FROM Product p with (NOLOCK)
		WHERE (p.VisibleIndividually = 1 ';
		if @ExportGrouped=1
		begin
			SET @sql = @sql+ 'OR p.ParentGroupedProductId!=0)'
		end
		else
		begin
			SET @sql = @sql+ ') AND p.ProductTypeId!=10'
		end
		SET @sql = @sql+' AND p.Published = 1
			AND p.Deleted = 0
			AND (getutcdate() BETWEEN ISNULL(p.AvailableStartDateTimeUtc, ''1/1/1900'') and ISNULL(p.AvailableEndDateTimeUtc, ''1/1/2999''))'
	
	--show hidden and ACL
		SET @sql = @sql + '
		AND (p.SubjectToAcl = 0 OR EXISTS (
			SELECT 1 FROM #FilteredCustomerRoleIds [fcr]
			WHERE
				[fcr].CustomerRoleId IN (
					SELECT [acl].CustomerRoleId
					FROM [AclRecord] acl with (NOLOCK)
					WHERE [acl].EntityId = p.Id AND [acl].EntityName = ''Product''
				)
			))'
	
	--show hidden and filter by store
	IF @StoreId > 0
	BEGIN
		SET @sql = @sql + '
		AND (p.LimitedToStores = 0 OR EXISTS (
			SELECT 1 FROM [StoreMapping] sm with (NOLOCK)
			WHERE [sm].EntityId = p.Id AND [sm].EntityName = ''Product'' and [sm].StoreId=' + CAST(@StoreId AS nvarchar(max)) + '
			))'
	END

	EXEC sp_executesql @sql
drop table #FilteredCustomerRoleIds

--delete empty grouped products
delete from #ExportProductsTmp where ProductTypeId=10 and ProductId not in (select ParentGroupedProductId from #ExportProductsTmp)

--delete subproducts (product variants) with parent product
delete from #ExportProductsTmp 
where ProductTypeId=5 and VisibleIndividually=0 and ParentGroupedProductId!=0 
	and ParentGroupedProductId not in (select ProductId from #ExportProductsTmp where ProductTypeId=10)

--Delete Non export products
CREATE TABLE #tmpFeedDefault (CategoryId int, ParentCategoryId int, ProductId int, Levelsort int, FeedCategoryId int, CategoryMap nvarchar(1000) null, DefaultValuesXML nvarchar(max) null, TypeActiveId int)

--FNS_FeedCategory
if exists(select * from FNS_FeedCategory F WITH (NOLOCK) where F.FeedId=@FeedId)
begin
	--Category tree
	create table #CategoryTree (Id int, ParentCategoryId int)
	insert into #CategoryTree(Id, ParentCategoryId)
	select Id, ParentCategoryId
	from Category C WITH (NOLOCK)
	where Deleted=0

	;with cte_tree (CategoryId, ParentCategoryId, Levelsort, FeedCategoryId, CategoryMap, DefaultValuesXML, TypeActiveId) as 
	(
		select C.Id as CategoryId, C.ParentCategoryId, 
			1 as Levelsort,
			isnull(F.CategoryId, 0) as FeedCategoryId,
			isnull(F.CategoryMap, convert(nvarchar(1000),null)) as CategoryMap,
			isnull(F.DefaultValuesXML, convert(nvarchar(max),null)) as DefaultValuesXML,
			isnull(F.TypeActiveId, 0) as TypeActiveId
		from #CategoryTree C WITH (NOLOCK)
			OUTER APPLY (select FC.* from FNS_FeedCategory FC WITH (NOLOCK) where C.Id=FC.CategoryId and FC.FeedId=@FeedId) as F
		where C.ParentCategoryId=0 --and C.Published=1
		union all
		select T.Id as CategoryId,T.ParentCategoryId as ParentCategoryId,
			C.Levelsort+1 as Levelsort,
			isnull(F.CategoryId, C.FeedCategoryId) as FeedCategoryId,
			isnull(F.CategoryMap, C.CategoryMap) as CategoryMap,
			isnull(F.DefaultValuesXML, C.DefaultValuesXML) as DefaultValuesXML,
			case 
				when F.TypeActiveId is null or F.TypeActiveId=0 then C.TypeActiveId
				else F.TypeActiveId
			end as TypeActiveId
		from cte_tree C,#CategoryTree T WITH (NOLOCK)
			OUTER APPLY (select FC.* from FNS_FeedCategory FC WITH (NOLOCK) where T.Id=FC.CategoryId and FC.FeedId=@FeedId) as F
		where C.CategoryId=T.ParentCategoryId --and T.Published=1
	)

	insert  into #tmpFeedDefault (CategoryId, ParentCategoryId, ProductId , Levelsort, FeedCategoryId, CategoryMap, DefaultValuesXML, TypeActiveId)
	select TOP 1 WITH TIES SM.CategoryId, isnull(C.ParentCategoryId,0), SM.ProductId , isnull(C.Levelsort,1), isnull(C.FeedCategoryId,0), C.CategoryMap, C.DefaultValuesXML, C.TypeActiveId
	from Product_Category_Mapping SM WITH (NOLOCK) 
		left join cte_tree C on SM.CategoryId=C.CategoryId
	where SM.ProductId in (select ProductId from #ExportProductsTmp)
		and SM.CategoryId in (select Id from #CategoryTree WITH (NOLOCK))
	ORDER BY ROW_NUMBER() OVER(PARTITION BY SM.ProductId 
			ORDER BY  
				case 
					when ISNULL(C.TypeActiveId,0)=0 then 0
					when ISNULL(C.TypeActiveId,0)=1 then -1
					when ISNULL(C.TypeActiveId,0)=2 then 2
				end ASC, 
				len(isnull(C.DefaultValuesXML,'')) desc, 
				SM.DisplayOrder
				)
	drop table #CategoryTree
end

--FNS_FeedProduct
if exists(select * from FNS_FeedProduct F WITH (NOLOCK) where F.FeedId=@FeedId)
begin
	insert  into #tmpFeedDefault (CategoryId, ParentCategoryId, ProductId , Levelsort, FeedCategoryId, CategoryMap, DefaultValuesXML, TypeActiveId)
	select 0 as CategoryId, 0 as ParentCategoryId, F.ProductId,0 as Levelsort,0 as FeedCategoryId, F.CategoryMap, F.DefaultValuesXML, F.TypeActiveId
	from FNS_FeedProduct F WITH (NOLOCK)
	where F.FeedId=@FeedId
end

--No Export
delete from #ExportProductsTmp where ProductId in (select ProductId from #tmpFeedDefault where TypeActiveId=2)
delete from #tmpFeedDefault where TypeActiveId=2

--Inherited = 0,
--Yes = 1
--No = 2
--delete from #ExportProductsTmp where ProductId not in (select ProductId from #tmpFeedDefault where TypeActiveId = 1)
--delete from #tmpFeedDefault where TypeActiveId<>1

--delete subproducts (product variants) with parent product
delete from #ExportProductsTmp 
where ProductTypeId=5 and VisibleIndividually=0 and ParentGroupedProductId!=0 
	and ParentGroupedProductId not in (select ProductId from #ExportProductsTmp where ProductTypeId=10)

--load unexported products for report
if @DisplayUnexportedProducts=1
begin
	select p.*
	from Product p WITH (NOLOCK)
	where p.Deleted = 0	
		AND p.Published = 1
		AND p.ProductTypeId=5 
		and (p.VisibleIndividually=1 or p.ParentGroupedProductId=0)
		and p.Id not in (select ProductId from #ExportProductsTmp)
	ORDER BY p.Id ASC
	drop table #ExportProductsTmp
	return
end
--paging
DECLARE @PageLowerBound int
DECLARE @PageUpperBound int
DECLARE @RowsToReturn int
SET @RowsToReturn = @PageSize * (@PageIndex + 1)	
SET @PageLowerBound = @PageSize * @PageIndex
SET @PageUpperBound = @PageLowerBound + @PageSize + 1

	CREATE TABLE #PageIndex 
	(
		[IndexId] int IDENTITY (1, 1) NOT NULL,
		[ProductId] int NOT NULL
	)
	INSERT INTO #PageIndex ([ProductId])
	SELECT ProductId
	FROM #ExportProductsTmp
	ORDER BY ProductId
	
	--return products
	create table #ExportProducts (ProductId int Not null) 
	insert into #ExportProducts (ProductId)
	select TOP (@RowsToReturn) [pi].ProductId
	FROM
		#PageIndex [pi]
	WHERE
		[pi].IndexId > @PageLowerBound AND 
		[pi].IndexId < @PageUpperBound
	ORDER BY
		[pi].IndexId
	
	DROP TABLE #PageIndex

select P.*
from Product P WITH (NOLOCK)
where P.Id in (select ProductId from #ExportProducts)
ORDER BY P.[Name] ASC


--select ProductId from #ExportProducts

select P.ProductId , P.Levelsort, P.FeedCategoryId, P.CategoryMap, P.DefaultValuesXML
from #tmpFeedDefault P 
where P.ProductId in (select ProductId from #ExportProducts)	
order by P.ProductId , P.Levelsort

drop table #tmpFeedDefault

If (@LanguageId>0)
begin
	select L.EntityId as ProductId,ltrim(rtrim(Substring(L.LocaleValue,1,400))) as Name
	from LocalizedProperty L WITH (NOLOCK) 
	where L.EntityId in (select ProductId from #ExportProducts) and L.LanguageId=@LanguageId and L.LocaleKeyGroup='Product' and L.LocaleKey='Name'
		and ltrim(rtrim(ISNULL(L.LocaleValue,'')))!=''

	select L.EntityId as ProductId,L.LocaleValue as ShortDescription
	from LocalizedProperty L WITH (NOLOCK) 
	where L.EntityId in (select ProductId from #ExportProducts) and L.LanguageId=@LanguageId and L.LocaleKeyGroup='Product' and L.LocaleKey='ShortDescription'
		and ltrim(rtrim(ISNULL(L.LocaleValue,'')))!=''
					
	select L.EntityId as ProductId,L.LocaleValue as FullDescription
	from LocalizedProperty L WITH (NOLOCK) 
	where L.EntityId in (select ProductId from #ExportProducts) and L.LanguageId=@LanguageId and L.LocaleKeyGroup='Product' and L.LocaleKey='FullDescription'
		and ltrim(rtrim(ISNULL(L.LocaleValue,'')))!=''
end
else
begin
	select TOP 0 ProductId,'' as Name
	from #ExportProducts
	
	select TOP 0 ProductId,'' as ShortDescription
	from #ExportProducts

	select TOP 0 ProductId,'' as FullDescription
	from #ExportProducts
end

--UrlRecord
create table #UrlRecord	(ProductId int,SeName nvarchar(400))

insert into #UrlRecord (ProductId,SeName)
select TOP 1 WITH TIES U.EntityId as ProductId,ltrim(rtrim(Substring(U.Slug,1,400))) as SeName
from UrlRecord U WITH (NOLOCK)
where U.EntityId in (select ProductId from #ExportProducts) 
	and U.EntityName='Product' and U.LanguageId=0 and U.IsActive=1 
	and ltrim(rtrim(U.Slug))!=''
ORDER BY ROW_NUMBER() OVER(PARTITION BY U.EntityId ORDER BY U.Id DESC)
			
If (@LanguageId>0)
begin
	update #UrlRecord
	set SeName=ltrim(rtrim(Substring(US.Slug,1,400)))
	from #UrlRecord C, (select TOP 1 WITH TIES U.EntityId,U.Slug
		from UrlRecord U WITH (NOLOCK)
		where U.EntityId in (select ProductId from #UrlRecord) 
			and U.EntityName='Product' and U.LanguageId=@LanguageId and U.IsActive=1
			and ltrim(rtrim(U.Slug))!=''
		ORDER BY ROW_NUMBER() OVER(PARTITION BY U.EntityId ORDER BY U.Id DESC)) US
	where C.ProductId=US.EntityId				
end
	
select * from  #UrlRecord
drop table #UrlRecord
--end UrlRecord

--Category
create table #tmp_Product_Category_Mapping (Id int, ProductId int, CategoryId int, DisplayOrder int)
insert #tmp_Product_Category_Mapping (Id, ProductId, CategoryId, DisplayOrder)
SELECT Id, ProductId, CategoryId, DisplayOrder
FROM Product_Category_Mapping WITH (NOLOCK)
WHERE ProductId in (select ProductId from #ExportProducts)

If (@LanguageId>0)
begin
	SELECT TOP 1 WITH TIES PM.ProductId,
			PM.CategoryId,C.ParentCategoryId,
			case 
				when L.LocaleValue IS NULL then C.Name collate SQL_Latin1_General_CP1_CI_AS
				when ltrim(rtrim(L.LocaleValue))=''  then C.Name collate SQL_Latin1_General_CP1_CI_AS
				else L.LocaleValue collate SQL_Latin1_General_CP1_CI_AS
			end as Name
	FROM #tmp_Product_Category_Mapping PM WITH (NOLOCK),Category C WITH (NOLOCK)
		left join LocalizedProperty L on C.Id=L.EntityId 
					and L.LocaleKeyGroup='Category' 
					and L.LocaleKey='Name' 
					and L.LanguageId=@LanguageId	
	WHERE PM.CategoryId=C.Id
		AND C.Deleted=0 and C.Published=1
		AND (@StoreId = 0 or C.LimitedToStores = 0 OR EXISTS (
			SELECT 1 FROM [StoreMapping] sm with (NOLOCK)
			WHERE [sm].EntityId = C.Id AND [sm].EntityName = 'Category' and [sm].StoreId=@StoreId))
	ORDER BY ROW_NUMBER() OVER(PARTITION BY PM.ProductId ORDER BY PM.DisplayOrder, PM.Id)
end
else
begin
	SELECT TOP 1 WITH TIES PM.ProductId,PM.CategoryId,C.ParentCategoryId,C.Name
	FROM #tmp_Product_Category_Mapping PM WITH (NOLOCK),Category C WITH (NOLOCK)
	WHERE PM.CategoryId=C.Id
		AND C.Deleted=0 and C.Published=1
		AND (@StoreId = 0 or C.LimitedToStores = 0 OR EXISTS (
			SELECT 1 FROM [StoreMapping] sm with (NOLOCK)
			WHERE [sm].EntityId = C.Id AND [sm].EntityName = 'Category' and [sm].StoreId=@StoreId))
	ORDER BY ROW_NUMBER() OVER(PARTITION BY PM.ProductId ORDER BY PM.DisplayOrder, PM.Id)
end
drop table #tmp_Product_Category_Mapping
--end Category

--Manufacturer
create table #tmp_Product_Manufacturer_Mapping (Id int, ProductId int, ManufacturerId int, DisplayOrder int)
insert #tmp_Product_Manufacturer_Mapping (Id, ProductId, ManufacturerId, DisplayOrder)
SELECT Id, ProductId, ManufacturerId, DisplayOrder
FROM Product_Manufacturer_Mapping WITH (NOLOCK)
WHERE ProductId in (select ProductId from #ExportProducts)

If (@LanguageId>0)
begin
	SELECT TOP 1 WITH TIES PM.ProductId,
			PM.ManufacturerId,
			case 
				when L.LocaleValue IS NULL then M.Name collate SQL_Latin1_General_CP1_CI_AS
				when ltrim(rtrim(L.LocaleValue))=''  then M.Name collate SQL_Latin1_General_CP1_CI_AS
				else L.LocaleValue collate SQL_Latin1_General_CP1_CI_AS
			end as Name
	FROM #tmp_Product_Manufacturer_Mapping PM WITH (NOLOCK),Manufacturer M WITH (NOLOCK)
		left join LocalizedProperty L on M.Id=L.EntityId 
					and L.LocaleKeyGroup='Manufacturer' 
					and L.LocaleKey='Name' 
					and L.LanguageId=@LanguageId	
	WHERE PM.ManufacturerId=M.Id
			AND M.Deleted=0 and M.Published=1
		AND (@StoreId = 0 or M.LimitedToStores = 0 OR EXISTS (
			SELECT 1 FROM [StoreMapping] sm with (NOLOCK)
			WHERE [sm].EntityId = M.Id AND [sm].EntityName = 'Manufacturer' and [sm].StoreId=@StoreId))
	ORDER BY ROW_NUMBER() OVER(PARTITION BY PM.ProductId ORDER BY PM.DisplayOrder, PM.Id)
end
else
begin
	SELECT TOP 1 WITH TIES PM.ProductId,PM.ManufacturerId,M.[Name]
	FROM #tmp_Product_Manufacturer_Mapping PM WITH (NOLOCK),Manufacturer M WITH (NOLOCK)
	WHERE PM.ManufacturerId=M.Id
			AND M.Deleted=0 and M.Published=1
		AND (@StoreId = 0 or M.LimitedToStores = 0 OR EXISTS (
			SELECT 1 FROM [StoreMapping] sm with (NOLOCK)
			WHERE [sm].EntityId = M.Id AND [sm].EntityName = 'Manufacturer' and [sm].StoreId=@StoreId))
	ORDER BY ROW_NUMBER() OVER(PARTITION BY PM.ProductId ORDER BY PM.DisplayOrder, PM.Id)
end
drop table #tmp_Product_Manufacturer_Mapping
--end Manufacturer

--Picture
	SELECT PM.ProductId,PM.DisplayOrder,P.Id,P.IsNew,P.MimeType,P.SeoFilename
	FROM Product_Picture_Mapping PM WITH (NOLOCK),Picture P WITH (NOLOCK)
	WHERE PM.PictureId=P.Id and PM.ProductId in (select ProductId from #ExportProducts)
	ORDER BY PM.ProductId,PM.DisplayOrder,PM.Id ASC
--end Picture

--Product Specification
create table #Product_SpecificationAttribute_Mapping (ProductId int, AttributeTypeId int, SpecificationAttributeOptionId int, CustomValue nvarchar(4000), ShowOnProductPage bit)

insert into #Product_SpecificationAttribute_Mapping (ProductId, AttributeTypeId, SpecificationAttributeOptionId, CustomValue, ShowOnProductPage)
select PM.ProductId, PM.AttributeTypeId, PM.SpecificationAttributeOptionId,PM.CustomValue,PM.ShowOnProductPage
from Product_SpecificationAttribute_Mapping PM WITH(NOLOCK)
where PM.ProductId in (select ProductId from #ExportProducts)

If (@LanguageId>0)
begin
	select distinct S.Id,PM.ProductId,
		case 
			when PM.CustomValue is not null and ltrim(rtrim(PM.CustomValue))!='' then PM.CustomValue collate SQL_Latin1_General_CP1_CI_AS
			when LSO.LocaleValue IS NULL or ltrim(rtrim(LSO.LocaleValue))='' then SO.Name collate SQL_Latin1_General_CP1_CI_AS
			else LSO.LocaleValue collate SQL_Latin1_General_CP1_CI_AS
			end as Value
	from SpecificationAttribute S WITH (NOLOCK),
		SpecificationAttributeOption SO WITH(NOLOCK)
			left join LocalizedProperty LSO WITH(NOLOCK) on SO.Id=LSO.EntityId 
					and LSO.LocaleKeyGroup='SpecificationAttributeOption' 
					and LSO.LocaleKey='Name' 
					and LSO.LanguageId=@LanguageId, 
		#Product_SpecificationAttribute_Mapping PM
	where S.Id=SO.SpecificationAttributeId 
		and SO.Id=PM.SpecificationAttributeOptionId
		and PM.AttributeTypeId in (0,10) --3.50
end
else
begin
	select distinct S.Id,PM.ProductId,
		case 
			when PM.CustomValue is not null and ltrim(rtrim(PM.CustomValue))!='' then PM.CustomValue collate SQL_Latin1_General_CP1_CI_AS
			else SO.Name collate SQL_Latin1_General_CP1_CI_AS
		end as Value
	from SpecificationAttribute S WITH (NOLOCK), 
		SpecificationAttributeOption SO WITH(NOLOCK), 
		#Product_SpecificationAttribute_Mapping PM
	where S.Id=SO.SpecificationAttributeId 
		and SO.Id=PM.SpecificationAttributeOptionId
		and PM.AttributeTypeId in (0,10) --3.50
end

drop table #Product_SpecificationAttribute_Mapping
--end Product Specification

--Product External Ids
select P.ProductId, A.[ASIN],E.[EPID] 
from #ExportProducts P 
	left join FNS_FeedASIN A WITH (NOLOCK) on P.ProductId=A.ProductId
	left join FNS_FeedEPID E WITH (NOLOCK) on P.ProductId=E.ProductId
where A.[ASIN] != null and E.[EPID] != null
--end Product Product External Ids

--FeedRequirement

--Quantity
if (exists(select * from FNS_FeedRequirement WITH(NOLOCK) 
	where FeedId=@FeedId and RequirementCategory='Product' and RequirementProperty='Quantity'))
begin
	select P.Id as ProductId, 
		StockQuantity=case 
		when P.ManageInventoryMethodId=1 and P.UseMultipleWarehouses=0 then P.StockQuantity
		when P.ManageInventoryMethodId=1 and P.UseMultipleWarehouses=1 then (
							select isnull(SUM(wpi.StockQuantity),0) as StockQuantity 
							from [ProductWarehouseInventory] wpi WITH (NOLOCK)
							where wpi.ProductId = P.Id)
		when P.ManageInventoryMethodId=2 then (select isnull(SUM(pac.StockQuantity),0) as StockQuantity 
						from [ProductAttributeCombination] pac WITH (NOLOCK)
						where pac.ProductId = P.Id)
		else 0
		end
	from Product P WITH(NOLOCK)
	where P.ProductTypeId!=10
		and P.Id in (select ProductId from #ExportProducts)
end
else
begin
	select top 0 P.Id as ProductId, StockQuantity
	from Product P WITH(NOLOCK)
end
--end Quantity

--Category
if (exists(select * from FNS_FeedRequirement WITH(NOLOCK) 
	where FeedId=@FeedId and RequirementCategory='Product' and RequirementProperty='Category'))
begin
	select distinct ProductId, CategoryId 
	from Product_Category_Mapping WITH(NOLOCK)
	where ProductId in (select ProductId from #ExportProducts)
	Order by ProductId
end
else
begin
	select top 0 ProductId, CategoryId 
	from Product_Category_Mapping WITH(NOLOCK)
end 
--end Category

--Manufacturer
if (exists(select * from FNS_FeedRequirement WITH(NOLOCK) 
	where FeedId=@FeedId and RequirementCategory='Product' and RequirementProperty='Manufacturer'))
begin
	select distinct ProductId, ManufacturerId 
	from Product_Manufacturer_Mapping WITH(NOLOCK)
	where ProductId in (select ProductId from #ExportProducts)
	Order by ProductId
end
else
begin
	select top 0 ProductId, ManufacturerId 
	from Product_Manufacturer_Mapping WITH(NOLOCK)
end 
--end Manufacturer

--end FeedRequirement
drop table #ExportProducts
END
GO
IF  EXISTS (SELECT * FROM sys.triggers WHERE object_id = OBJECT_ID(N'[Tri_Insert_Product_FeedManager]'))
DROP TRIGGER [Tri_Insert_Product_FeedManager]
GO

